package ctbrec.ui.sites.chaturbate;

import java.util.ArrayList;
import java.util.List;

import ctbrec.Config;
import ctbrec.sites.chaturbate.Chaturbate;
import ctbrec.ui.DesktopIntegration;
import ctbrec.ui.settings.SettingsTab;
import ctbrec.ui.sites.AbstractConfigUI;
import javafx.geometry.Insets;
import javafx.scene.Parent;
import javafx.scene.control.*;
import javafx.scene.layout.GridPane;
// import javafx.scene.layout.HBox;
import javafx.scene.layout.Priority;

public class ChaturbateConfigUi extends AbstractConfigUI {
    private Chaturbate chaturbate;

    public ChaturbateConfigUi(Chaturbate chaturbate) {
        this.chaturbate = chaturbate;
    }

    @Override
    public Parent createConfigPanel() {
        var settings = Config.getInstance().getSettings();
        GridPane layout = SettingsTab.createGridLayout();

        var row = 0;
        var l = new Label("Active");
        layout.add(l, 0, row);
        var enabled = new CheckBox();
        enabled.setSelected(!settings.disabledSites.contains(chaturbate.getName()));
        enabled.setOnAction(e -> {
            if(enabled.isSelected()) {
                settings.disabledSites.remove(chaturbate.getName());
            } else {
                settings.disabledSites.add(chaturbate.getName());
            }
            save();
        });
        GridPane.setMargin(enabled, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        layout.add(enabled, 1, row++);

        layout.add(new Label("Chaturbate User"), 0, row);
        var username = new TextField(Config.getInstance().getSettings().chaturbateUsername);
        username.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().chaturbateUsername)) {
                Config.getInstance().getSettings().chaturbateUsername = n;
                chaturbate.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(username, true);
        GridPane.setHgrow(username, Priority.ALWAYS);
        GridPane.setColumnSpan(username, 2);
        layout.add(username, 1, row++);

        layout.add(new Label("Chaturbate Password"), 0, row);
        var password = new PasswordField();
        password.setText(Config.getInstance().getSettings().chaturbatePassword);
        password.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().chaturbatePassword)) {
                Config.getInstance().getSettings().chaturbatePassword = n;
                chaturbate.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(password, true);
        GridPane.setHgrow(password, Priority.ALWAYS);
        GridPane.setColumnSpan(password, 2);
        layout.add(password, 1, row++);

        layout.add(new Label("Chaturbate Base URL"), 0, row);
        var baseUrl = new TextField();
        baseUrl.setText(Config.getInstance().getSettings().chaturbateBaseUrl);
        baseUrl.textProperty().addListener((ob, o, n) -> {
            Config.getInstance().getSettings().chaturbateBaseUrl = baseUrl.getText();
            save();
        });
        GridPane.setFillWidth(baseUrl, true);
        GridPane.setHgrow(baseUrl, Priority.ALWAYS);
        GridPane.setColumnSpan(baseUrl, 2);
        layout.add(baseUrl, 1, row++);

        layout.add(new Label("Time between requests (ms)"), 0, row);
        var requestThrottle = new TextField(Integer.toString(Config.getInstance().getSettings().chaturbateMsBetweenRequests));
        requestThrottle.textProperty().addListener((ob, o, n) -> {
            int newValue = -1;
            try {
                newValue = Integer.parseInt(n);
            } catch (Exception e) {
                requestThrottle.setText(o);
                return;
            }
            if (newValue != Config.getInstance().getSettings().chaturbateMsBetweenRequests) {
                Config.getInstance().getSettings().chaturbateMsBetweenRequests = newValue;
                save();
            }
        });
        GridPane.setFillWidth(requestThrottle, true);
        GridPane.setHgrow(requestThrottle, Priority.ALWAYS);
        GridPane.setColumnSpan(requestThrottle, 2);
        layout.add(requestThrottle, 1, row++);

        Label tabsLabel = new Label("Tabs");
        layout.add(tabsLabel, 0, row);
        List<String> tabs = getEnabledTabs();

        GridPane checkboxGrid = new GridPane();
        checkboxGrid.setHgap(10);
        checkboxGrid.setVgap(5);
        checkboxGrid.setPadding(new Insets(0, 0, 0, 7));

        CheckBox female = new CheckBox("Female");
        female.setSelected(tabs.contains("f"));
        female.setOnAction(e -> toggleTab("f", female.isSelected()));
        checkboxGrid.add(female, 0, 0);

        CheckBox newFemale = new CheckBox("New Female");
        newFemale.setSelected(tabs.contains("nf"));
        newFemale.setOnAction(e -> toggleTab("nf", newFemale.isSelected()));
        checkboxGrid.add(newFemale, 1, 0);

        CheckBox male = new CheckBox("Male");
        male.setSelected(tabs.contains("m"));
        male.setOnAction(e -> toggleTab("m", male.isSelected()));
        checkboxGrid.add(male, 2, 0);

        CheckBox newMale = new CheckBox("New Male");
        newMale.setSelected(tabs.contains("nm"));
        newMale.setOnAction(e -> toggleTab("nm", newMale.isSelected()));
        checkboxGrid.add(newMale, 3, 0);

        CheckBox couples = new CheckBox("Couples");
        couples.setSelected(tabs.contains("c"));
        couples.setOnAction(e -> toggleTab("c", couples.isSelected()));
        checkboxGrid.add(couples, 0, 1);

        CheckBox trans = new CheckBox("Trans");
        trans.setSelected(tabs.contains("t"));
        trans.setOnAction(e -> toggleTab("t", trans.isSelected()));
        checkboxGrid.add(trans, 1, 1);

        CheckBox pvt = new CheckBox("Private");
        pvt.setSelected(tabs.contains("xp"));
        pvt.setOnAction(e -> toggleTab("xp", pvt.isSelected()));
        checkboxGrid.add(pvt, 2, 1);

        CheckBox hidden = new CheckBox("Hidden");
        hidden.setSelected(tabs.contains("xh"));
        hidden.setOnAction(e -> toggleTab("xh", hidden.isSelected()));
        checkboxGrid.add(hidden, 3, 1);

        CheckBox gaming = new CheckBox("Gaming");
        gaming.setSelected(tabs.contains("xg"));
        gaming.setOnAction(e -> toggleTab("xg", gaming.isSelected()));
        checkboxGrid.add(gaming, 0, 2);

        CheckBox feat = new CheckBox("Featured");
        feat.setSelected(tabs.contains("ft"));
        feat.setOnAction(e -> toggleTab("ft", feat.isSelected()));
        checkboxGrid.add(feat, 1, 2);

        CheckBox top = new CheckBox("Top Rated");
        top.setSelected(tabs.contains("ar"));
        top.setOnAction(e -> toggleTab("ar", top.isSelected()));
        checkboxGrid.add(top, 2, 2);

        CheckBox trend = new CheckBox("Trending");
        trend.setSelected(tabs.contains("at"));
        trend.setOnAction(e -> toggleTab("at", trend.isSelected()));
        checkboxGrid.add(trend, 3, 2);

        CheckBox asiaOther = new CheckBox("Asia/Oth");
        asiaOther.setSelected(tabs.contains("AS,O"));
        asiaOther.setOnAction(e -> toggleTab("AS,O", asiaOther.isSelected()));
        checkboxGrid.add(asiaOther, 0, 3);

        CheckBox euRu = new CheckBox("Eu/Ru");
        euRu.setSelected(tabs.contains("ER"));
        euRu.setOnAction(e -> toggleTab("ER", euRu.isSelected()));
        checkboxGrid.add(euRu, 1, 3);

        CheckBox nthAm = new CheckBox("Nth Am");
        nthAm.setSelected(tabs.contains("NA"));
        nthAm.setOnAction(e -> toggleTab("NA", nthAm.isSelected()));
        checkboxGrid.add(nthAm, 2, 3);

        CheckBox sthAm = new CheckBox("Sth Am");
        sthAm.setSelected(tabs.contains("SA"));
        sthAm.setOnAction(e -> toggleTab("SA", sthAm.isSelected()));
        checkboxGrid.add(sthAm, 3, 3);

        layout.add(checkboxGrid, 1, row, 4, 4);
        row += 4;
        
        var createAccount = new Button("Create new Account");
        createAccount.setOnAction(e -> DesktopIntegration.open(Chaturbate.REGISTRATION_LINK));
        layout.add(createAccount, 1, row++);
        GridPane.setColumnSpan(createAccount, 2);

        var deleteCookies = new Button("Delete Cookies");
        deleteCookies.setOnAction(e -> chaturbate.getHttpClient().clearCookies());
        layout.add(deleteCookies, 1, row);
        GridPane.setColumnSpan(deleteCookies, 2);

        GridPane.setMargin(username, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(password, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(baseUrl, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(requestThrottle, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(createAccount, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(deleteCookies, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));

        username.setPrefWidth(300);

        return layout;
    }
    private void toggleTab(String region, boolean selected) {
        var settings = Config.getInstance().getSettings();
        if (selected) {
            settings.chaturbateTabs.add(region);
        } else {
            settings.chaturbateTabs.remove(region);
        }
        save();
    }

    private List<String> getEnabledTabs() {
        return new ArrayList<>(Config.getInstance().getSettings().chaturbateTabs);
    }
}
