package ctbrec.ui.sites.chaturbate;

import ctbrec.Config;
import ctbrec.sites.chaturbate.Chaturbate;
import ctbrec.ui.sites.AbstractTabProvider;
import ctbrec.ui.tabs.PaginatedScheduledService;
import ctbrec.ui.tabs.ThumbOverviewTab;
import javafx.scene.Scene;
import javafx.scene.control.Tab;

import java.util.ArrayList;
// import java.util.HashMap;
import java.util.List;
// import java.util.Map;
import java.util.regex.Pattern;

public class ChaturbateTabProvider extends AbstractTabProvider {

    private final String apiUrl;
    private final ChaturbateFollowedTab followedTab;

    public ChaturbateTabProvider(Chaturbate chaturbate) {
        super(chaturbate);
        apiUrl = site.getBaseUrl() + "/api/ts";
        this.followedTab = new ChaturbateFollowedTab("Followed", apiUrl + "/roomlist/room-list/?enable_recommendations=false&follow=true", chaturbate);
    }

    @Override
    protected List<Tab> getSiteTabs(Scene scene) {
        List<Tab> tabs = new ArrayList<>();
        
        for (String tab : getEnabledTabs()) {
            switch (tab) {
                case "ft":
                    tabs.add(createTab("Featured", apiUrl + "/roomlist/room-list/?enable_recommendations=false"));
                    break;
                case "f":
                case "m":
                case "c":
                case "t":
                    tabs.add(createTab("Female", apiUrl + "/roomlist/room-list/?enable_recommendations=false&genders=" + tab));
                    break;
                case "nf":
                    addNewCamsTab(tabs, "New Female", "f");
                    break;
                case "nm":
                    addNewCamsTab(tabs, "New Male", "m");
                    break;
                case "xp":
                    tabs.add(createTab("Private", apiUrl + "/roomlist/room-list/?enable_recommendations=false&private=true"));
                    break;
                case "xh":
                    tabs.add(createTab("Hidden", apiUrl + "/roomlist/room-list/?enable_recommendations=false&hidden=true"));
                    break;
                case "xg":
                    tabs.add(createTab("Gaming", apiUrl + "/roomlist/room-list/?enable_recommendations=false&gaming=true"));
                    break;
                case "ar":
                    tabs.add(createApiTab("Top Rated", apiUrl + "/discover/carousels/top-rated/"));
                    break;
                case "at":
                    tabs.add(createApiTab("Trending", apiUrl + "/discover/carousels/trending/"));
                    break;
                default:
                    if (Pattern.matches("^[A-Z].+", tab)) {
                        addRegionBasedTab(tabs, tab);
                    }
                    break;
            }
        }
        
        return tabs;
    }
    
    private void addNewCamsTab(List<Tab> tabs, String title, String gender) {
        tabs.add(createTab(title, apiUrl + "/roomlist/room-list/?enable_recommendations=false&genders=" + gender + "&new_cams=true"));
    }
    
    private void addRegionBasedTab(List<Tab> tabs, String regionCode) {
        String regions = getRegionTitle(regionCode);
        if (regions != null) {
            tabs.add(createTab(regions, apiUrl + "/roomlist/room-list/?enable_recommendations=false&regions=" + regionCode));
        }
    }
    
    private String getRegionTitle(String regionCode) {
        switch (regionCode) {
            case "AS,O":
                return "Asia/Oth";
            case "ER":
                return "Eu/Ru";
            case "NA":
                return "Nth Amer";
            case "SA":
                return "Sth Amer";
            default:
                return null;
        }
    }

    @Override
    public Tab getFollowedTab() {
        return followedTab;
    }

    private Tab createTab(String title, String url) {
        var updateService = new ChaturbateUpdateService(url, false, (Chaturbate) site);
        return createTab(title, updateService);
    }

    private Tab createTab(String title, PaginatedScheduledService updateService) {
        var tab = new ThumbOverviewTab(title, updateService, site);
        tab.setRecorder(recorder);
        tab.setImageAspectRatio(9.0 / 16.0);
        return tab;
    }

    private Tab createApiTab(String title, String apiUrl) {
        var updateService = new ChaturbateApiUpdateService(apiUrl, (Chaturbate) site);
        return createTab(title, updateService);
    }

    private List<String> getEnabledTabs() {
        return new ArrayList<>(Config.getInstance().getSettings().chaturbateTabs);
    }
}
