package ctbrec.ui.sites.flirt4free;

import java.util.ArrayList;
import java.util.List;

import ctbrec.Config;
import ctbrec.sites.flirt4free.Flirt4Free;
import ctbrec.ui.DesktopIntegration;
import ctbrec.ui.settings.SettingsTab;
import ctbrec.ui.sites.AbstractConfigUI;
import javafx.geometry.Insets;
import javafx.scene.Parent;
import javafx.scene.control.Button;
import javafx.scene.control.CheckBox;
import javafx.scene.control.Label;
import javafx.scene.control.PasswordField;
import javafx.scene.control.TextField;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.Priority;

public class Flirt4FreeConfigUI extends AbstractConfigUI {
    private Flirt4Free flirt4free;

    public Flirt4FreeConfigUI(Flirt4Free flirt4free) {
        this.flirt4free = flirt4free;
    }

    @Override
    public Parent createConfigPanel() {
        var layout = SettingsTab.createGridLayout();
        var settings = Config.getInstance().getSettings();

        var row = 0;
        var l = new Label("Active");
        layout.add(l, 0, row);
        var enabled = new CheckBox();
        enabled.setSelected(!settings.disabledSites.contains(flirt4free.getName()));
        enabled.setOnAction(e -> {
            if(enabled.isSelected()) {
                settings.disabledSites.remove(flirt4free.getName());
            } else {
                settings.disabledSites.add(flirt4free.getName());
            }
            save();
        });
        GridPane.setMargin(enabled, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        layout.add(enabled, 1, row++);

        layout.add(new Label("Flirt4Free User"), 0, row);
        var username = new TextField(settings.flirt4freeUsername);
        username.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().flirt4freeUsername)) {
                Config.getInstance().getSettings().flirt4freeUsername = username.getText();
                flirt4free.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(username, true);
        GridPane.setHgrow(username, Priority.ALWAYS);
        GridPane.setColumnSpan(username, 2);
        layout.add(username, 1, row++);

        layout.add(new Label("Flirt4Free Password"), 0, row);
        var password = new PasswordField();
        password.setText(settings.flirt4freePassword);
        password.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().flirt4freePassword)) {
                Config.getInstance().getSettings().flirt4freePassword = password.getText();
                flirt4free.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(password, true);
        GridPane.setHgrow(password, Priority.ALWAYS);
        GridPane.setColumnSpan(password, 2);
        layout.add(password, 1, row++);

        Label tabsLabel = new Label("Tabs");
        layout.add(tabsLabel, 0, row);
        List<String> tabs = getEnabledTabs();

        GridPane checkboxGrid = new GridPane();
        checkboxGrid.setHgap(10);
        checkboxGrid.setVgap(5);
        checkboxGrid.setPadding(new Insets(0, 0, 0, 7));

        CheckBox female = new CheckBox("Female");
        female.setSelected(tabs.contains("female"));
        female.setOnAction(e -> toggleTab("female", female.isSelected()));
        checkboxGrid.add(female, 0, 0);

        CheckBox newModels = new CheckBox("Girls New");
        newModels.setSelected(tabs.contains("hd"));
        newModels.setOnAction(e -> toggleTab("hd", newModels.isSelected()));
        checkboxGrid.add(newModels, 1, 0);

        CheckBox male = new CheckBox("Male");
        male.setSelected(tabs.contains("male"));
        male.setOnAction(e -> toggleTab("male", male.isSelected()));
        checkboxGrid.add(male, 2, 0);

        CheckBox couples = new CheckBox("Couples");
        couples.setSelected(tabs.contains("couples"));
        couples.setOnAction(e -> toggleTab("couples", couples.isSelected()));
        checkboxGrid.add(couples, 0, 1);

        CheckBox trans = new CheckBox("Trans");
        trans.setSelected(tabs.contains("trans"));
        trans.setOnAction(e -> toggleTab("trans", trans.isSelected()));
        checkboxGrid.add(trans, 1, 1);

        layout.add(checkboxGrid, 1, row, 3, 2);
        row += 2;

        var createAccount = new Button("Create new Account");
        createAccount.setOnAction(e -> DesktopIntegration.open(flirt4free.getAffiliateLink()));
        layout.add(createAccount, 1, row++);
        GridPane.setColumnSpan(createAccount, 2);

        var deleteCookies = new Button("Delete Cookies");
        deleteCookies.setOnAction(e -> flirt4free.getHttpClient().clearCookies());
        layout.add(deleteCookies, 1, row);
        GridPane.setColumnSpan(deleteCookies, 2);

        GridPane.setMargin(username, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(password, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(createAccount, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(deleteCookies, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        return layout;
    }

    private void toggleTab(String tab, boolean selected) {
        var settings = Config.getInstance().getSettings();
        if (selected) {
            settings.cam4Tabs.add(tab);
        } else {
            settings.cam4Tabs.remove(tab);
        }
        save();
    }

    private List<String> getEnabledTabs() {
        return new ArrayList<>(Config.getInstance().getSettings().cam4Tabs);
    }

}
