package ctbrec.ui.sites.showup;

import java.util.ArrayList;
import java.util.List;

import ctbrec.Config;
import ctbrec.sites.showup.Showup;
import ctbrec.ui.DesktopIntegration;
import ctbrec.ui.settings.SettingsTab;
import ctbrec.ui.sites.AbstractConfigUI;
import javafx.geometry.Insets;
import javafx.scene.Parent;
import javafx.scene.control.Button;
import javafx.scene.control.CheckBox;
import javafx.scene.control.Label;
import javafx.scene.control.PasswordField;
import javafx.scene.control.TextField;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Priority;

public class ShowupConfigUI extends AbstractConfigUI {
    private Showup site;

    public ShowupConfigUI(Showup site) {
        this.site = site;
    }

    @Override
    public Parent createConfigPanel() {
        GridPane layout = SettingsTab.createGridLayout();
        var settings = Config.getInstance().getSettings();

        var row = 0;
        var l = new Label("Active");
        layout.add(l, 0, row);
        var enabled = new CheckBox();
        enabled.setSelected(!settings.disabledSites.contains(site.getName()));
        enabled.setOnAction(e -> {
            if(enabled.isSelected()) {
                settings.disabledSites.remove(site.getName());
            } else {
                settings.disabledSites.add(site.getName());
            }
            save();
        });
        GridPane.setMargin(enabled, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        layout.add(enabled, 1, row++);

        layout.add(new Label("Showup User"), 0, row);
        var username = new TextField(Config.getInstance().getSettings().showupUsername);
        username.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().showupUsername)) {
                Config.getInstance().getSettings().showupUsername = username.getText();
                site.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(username, true);
        GridPane.setHgrow(username, Priority.ALWAYS);
        GridPane.setColumnSpan(username, 2);
        layout.add(username, 1, row++);

        layout.add(new Label("Showup Password"), 0, row);
        var password = new PasswordField();
        password.setText(Config.getInstance().getSettings().showupPassword);
        password.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().showupPassword)) {
                Config.getInstance().getSettings().showupPassword = password.getText();
                site.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(password, true);
        GridPane.setHgrow(password, Priority.ALWAYS);
        GridPane.setColumnSpan(password, 2);
        layout.add(password, 1, row++);

        Label tabsLabel = new Label("Tabs");
        layout.add(tabsLabel, 0, row);
        List<String> tabs = getEnabledTabs();

        HBox checkboxContainer = new HBox(10);

        CheckBox female = new CheckBox("Female");
        female.setSelected(tabs.contains("female"));
        female.setOnAction(e -> toggleTab("female", female.isSelected()));
        HBox.setMargin(female, new Insets(0, 0, 0, 8));
        checkboxContainer.getChildren().add(female);

        CheckBox male = new CheckBox("Male");
        male.setSelected(tabs.contains("m"));
        male.setOnAction(e -> toggleTab("m", male.isSelected()));
        checkboxContainer.getChildren().add(male);

        CheckBox all = new CheckBox("All");
        all.setSelected(tabs.contains("all"));
        all.setOnAction(e -> toggleTab("all", all.isSelected()));
        checkboxContainer.getChildren().add(all);

        layout.add(checkboxContainer, 1, row, 3, 1);
        row++;

        var createAccount = new Button("Create new Account");
        createAccount.setOnAction(e -> DesktopIntegration.open(site.getAffiliateLink()));
        layout.add(createAccount, 1, row++);
        GridPane.setColumnSpan(createAccount, 2);

        var deleteCookies = new Button("Delete Cookies");
        deleteCookies.setOnAction(e -> site.getHttpClient().clearCookies());
        layout.add(deleteCookies, 1, row);
        GridPane.setColumnSpan(deleteCookies, 2);

        GridPane.setMargin(username, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(password, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(createAccount, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(deleteCookies, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        return layout;
    }

    private void toggleTab(String tab, boolean selected) {
        var settings = Config.getInstance().getSettings();
        if (selected) {
            settings.showupTabs.add(tab);
        } else {
            settings.showupTabs.remove(tab);
        }
        save();
    }

    private List<String> getEnabledTabs() {
        return new ArrayList<>(Config.getInstance().getSettings().showupTabs);
    }

}
