package ctbrec.ui.sites.streamate;

import java.util.ArrayList;
import java.util.List;

import ctbrec.Config;
import ctbrec.sites.streamate.Streamate;
import ctbrec.ui.DesktopIntegration;
import ctbrec.ui.settings.SettingsTab;
import ctbrec.ui.sites.AbstractConfigUI;
import javafx.geometry.Insets;
import javafx.scene.Parent;
import javafx.scene.control.Button;
import javafx.scene.control.CheckBox;
import javafx.scene.control.Label;
import javafx.scene.control.PasswordField;
import javafx.scene.control.TextField;
import javafx.scene.layout.GridPane;
// import javafx.scene.layout.HBox;
import javafx.scene.layout.Priority;

public class StreamateConfigUI extends AbstractConfigUI {
    private Streamate streamate;

    public StreamateConfigUI(Streamate streamate) {
        this.streamate = streamate;
    }

    @Override
    public Parent createConfigPanel() {
        GridPane layout = SettingsTab.createGridLayout();
        var settings = Config.getInstance().getSettings();

        var row = 0;
        var l = new Label("Active");
        layout.add(l, 0, row);
        var enabled = new CheckBox();
        enabled.setSelected(!settings.disabledSites.contains(streamate.getName()));
        enabled.setOnAction(e -> {
            if(enabled.isSelected()) {
                settings.disabledSites.remove(streamate.getName());
            } else {
                settings.disabledSites.add(streamate.getName());
            }
            save();
        });
        GridPane.setMargin(enabled, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        layout.add(enabled, 1, row++);

        layout.add(new Label("Streamate User"), 0, row);
        var username = new TextField(settings.streamateUsername);
        username.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().streamateUsername)) {
                Config.getInstance().getSettings().streamateUsername = username.getText();
                streamate.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(username, true);
        GridPane.setHgrow(username, Priority.ALWAYS);
        GridPane.setColumnSpan(username, 2);
        layout.add(username, 1, row++);

        layout.add(new Label("Streamate Password"), 0, row);
        var password = new PasswordField();
        password.setText(settings.streamatePassword);
        password.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().streamatePassword)) {
                Config.getInstance().getSettings().streamatePassword = password.getText();
                streamate.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(password, true);
        GridPane.setHgrow(password, Priority.ALWAYS);
        GridPane.setColumnSpan(password, 2);
        layout.add(password, 1, row++);

        Label tabsLabel = new Label("Tabs");
        layout.add(tabsLabel, 0, row);
        List<String> tabs = getEnabledTabs();

        GridPane checkboxGrid = new GridPane();
        checkboxGrid.setHgap(10);
        checkboxGrid.setVgap(5);
        checkboxGrid.setPadding(new Insets(0, 0, 0, 7));

        CheckBox female = new CheckBox("Girls");
        female.setSelected(tabs.contains("f,ff"));
        female.setOnAction(e -> toggleTab("f,ff", female.isSelected()));
        checkboxGrid.add(female, 0, 0);

        CheckBox male = new CheckBox("Guys");
        male.setSelected(tabs.contains("m"));
        male.setOnAction(e -> toggleTab("m", male.isSelected()));
        checkboxGrid.add(male, 1, 0);

        CheckBox couples = new CheckBox("Couples");
        couples.setSelected(tabs.contains("mf,mm"));
        couples.setOnAction(e -> toggleTab("mf,mm", couples.isSelected()));
        checkboxGrid.add(couples, 2, 0);

        CheckBox trans = new CheckBox("Trans");
        trans.setSelected(tabs.contains("tm2f,tf2m"));
        trans.setOnAction(e -> toggleTab("tm2f,tf2m", trans.isSelected()));
        checkboxGrid.add(trans, 0, 1);

        CheckBox newGirls = new CheckBox("Girls New");
        newGirls.setSelected(tabs.contains("fn"));
        newGirls.setOnAction(e -> toggleTab("fn", newGirls.isSelected()));
        checkboxGrid.add(newGirls, 1, 1);

        CheckBox newModels = new CheckBox("New");
        newModels.setSelected(tabs.contains("new"));
        newModels.setOnAction(e -> toggleTab("new", newModels.isSelected()));
        checkboxGrid.add(newModels, 2, 1);

        layout.add(checkboxGrid, 1, row, 3, 2);
        row += 2;

        var createAccount = new Button("Create new Account");
        createAccount.setOnAction(e -> DesktopIntegration.open(streamate.getAffiliateLink()));
        layout.add(createAccount, 1, row++);
        GridPane.setColumnSpan(createAccount, 2);

        var deleteCookies = new Button("Delete Cookies");
        deleteCookies.setOnAction(e -> streamate.getHttpClient().clearCookies());
        layout.add(deleteCookies, 1, row);
        GridPane.setColumnSpan(deleteCookies, 2);

        GridPane.setMargin(username, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(password, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(createAccount, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(deleteCookies, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        return layout;
    }

    private void toggleTab(String tab, boolean selected) {
        var settings = Config.getInstance().getSettings();
        if (selected) {
            settings.streamateTabs.add(tab);
        } else {
            settings.streamateTabs.remove(tab);
        }
        save();
    }

    private List<String> getEnabledTabs() {
        return new ArrayList<>(Config.getInstance().getSettings().streamateTabs);
    }

}
