package ctbrec.ui.sites.streamray;

import java.util.ArrayList;
import java.util.List;

import ctbrec.Config;
import ctbrec.sites.streamray.Streamray;
import ctbrec.ui.settings.SettingsTab;
import ctbrec.ui.sites.AbstractConfigUI;
import javafx.geometry.Insets;
import javafx.scene.Parent;
// import javafx.scene.control.ToggleGroup;
import javafx.scene.control.Button;
import javafx.scene.control.CheckBox;
// import javafx.scene.control.RadioButton;
import javafx.scene.control.Label;
import javafx.scene.layout.GridPane;
// import javafx.scene.layout.HBox;
import javafx.scene.layout.HBox;

public class StreamrayConfigUI extends AbstractConfigUI {
    private final Streamray site;

    public StreamrayConfigUI(Streamray site) {
        this.site = site;
    }

    @Override
    public Parent createConfigPanel() {
        GridPane layout = SettingsTab.createGridLayout();
        var settings = Config.getInstance().getSettings();

        var row = 0;
        var l = new Label("Active");
        layout.add(l, 0, row);
        var enabled = new CheckBox();
        enabled.setSelected(!settings.disabledSites.contains(site.getName()));
        enabled.setOnAction(e -> {
            if(enabled.isSelected()) {
                settings.disabledSites.remove(site.getName());
            } else {
                settings.disabledSites.add(site.getName());
            }
            save();
        });
        GridPane.setMargin(enabled, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        layout.add(enabled, 1, row++);
        row++;
        
        l = new Label("Record Goal/Tipping shows");
        layout.add(l, 0, row);
        var cb = new CheckBox();
        cb.setSelected(settings.streamrayRecordGoalShows);
        cb.setOnAction(e -> {
            settings.streamrayRecordGoalShows = cb.isSelected();
            save();
        });
        GridPane.setMargin(cb, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        layout.add(cb, 1, row++);
        row++;

        Label tabsLabel = new Label("Tabs");
        layout.add(tabsLabel, 0, row);
        List<String> tabs = getEnabledTabs();

        HBox checkboxContainer = new HBox(10);

        CheckBox female = new CheckBox("Female");
        female.setSelected(tabs.contains("F"));
        female.setOnAction(e -> toggleTab("F", female.isSelected()));
        HBox.setMargin(female, new Insets(0, 0, 0, 7));
        checkboxContainer.getChildren().add(female);

        CheckBox male = new CheckBox("Male");
        male.setSelected(tabs.contains("M"));
        male.setOnAction(e -> toggleTab("M", male.isSelected()));
        checkboxContainer.getChildren().add(male);

        CheckBox all = new CheckBox("Trans");
        all.setSelected(tabs.contains("TS"));
        all.setOnAction(e -> toggleTab("TS", all.isSelected()));
        checkboxContainer.getChildren().add(all);

        layout.add(checkboxContainer, 1, row, 4, 1);
        row++;

        var deleteCookies = new Button("Delete Cookies");
        deleteCookies.setOnAction(e -> site.getHttpClient().clearCookies());
        layout.add(deleteCookies, 1, row);
        GridPane.setColumnSpan(deleteCookies, 2);

        GridPane.setMargin(deleteCookies, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        return layout;
    }

    private void toggleTab(String tab, boolean selected) {
        var settings = Config.getInstance().getSettings();
        if (selected) {
            settings.streamrayTabs.add(tab);
        } else {
            settings.streamrayTabs.remove(tab);
        }
        save();
    }

    private List<String> getEnabledTabs() {
        return new ArrayList<>(Config.getInstance().getSettings().streamrayTabs);
    }

}
