package ctbrec.ui.sites.xlovecam;

import java.util.ArrayList;
import java.util.List;

import ctbrec.Config;
import ctbrec.sites.xlovecam.XloveCam;
import ctbrec.ui.DesktopIntegration;
import ctbrec.ui.settings.SettingsTab;
import ctbrec.ui.sites.AbstractConfigUI;
import javafx.geometry.Insets;
import javafx.scene.Parent;
import javafx.scene.control.Button;
import javafx.scene.control.CheckBox;
import javafx.scene.control.Label;
import javafx.scene.control.PasswordField;
import javafx.scene.control.TextField;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.Priority;

public class XloveCamConfigUI extends AbstractConfigUI {
    private XloveCam site;

    public XloveCamConfigUI(XloveCam site) {
        this.site = site;
    }

    @Override
    public Parent createConfigPanel() {
        GridPane layout = SettingsTab.createGridLayout();
        var settings = Config.getInstance().getSettings();

        var row = 0;
        var l = new Label("Active");
        layout.add(l, 0, row);
        var enabled = new CheckBox();
        enabled.setSelected(!settings.disabledSites.contains(site.getName()));
        enabled.setOnAction(e -> {
            if(enabled.isSelected()) {
                settings.disabledSites.remove(site.getName());
            } else {
                settings.disabledSites.add(site.getName());
            }
            save();
        });
        GridPane.setMargin(enabled, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        layout.add(enabled, 1, row++);

        layout.add(new Label("XloveCam User"), 0, row);
        var username = new TextField(Config.getInstance().getSettings().xlovecamUsername);
        username.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().xlovecamUsername)) {
                Config.getInstance().getSettings().xlovecamUsername = username.getText();
                site.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(username, true);
        GridPane.setHgrow(username, Priority.ALWAYS);
        GridPane.setColumnSpan(username, 2);
        layout.add(username, 1, row++);

        layout.add(new Label("XloveCam Password"), 0, row);
        var password = new PasswordField();
        password.setText(Config.getInstance().getSettings().xlovecamPassword);
        password.textProperty().addListener((ob, o, n) -> {
            if(!n.equals(Config.getInstance().getSettings().xlovecamPassword)) {
                Config.getInstance().getSettings().xlovecamPassword = password.getText();
                site.getHttpClient().logout();
                save();
            }
        });
        GridPane.setFillWidth(password, true);
        GridPane.setHgrow(password, Priority.ALWAYS);
        GridPane.setColumnSpan(password, 2);
        layout.add(password, 1, row++);

        Label tabsLabel = new Label("Tabs");
        layout.add(tabsLabel, 0, row);
        List<String> tabs = getEnabledTabs();

        GridPane checkboxGrid = new GridPane();
        checkboxGrid.setHgap(10);
        checkboxGrid.setVgap(5);
        checkboxGrid.setPadding(new Insets(0, 0, 0, 7));

        CheckBox girls = new CheckBox("Young Women");
        girls.setSelected(tabs.contains("1"));
        girls.setOnAction(e -> toggleTab("1", girls.isSelected()));
        checkboxGrid.add(girls, 0, 0);
        
        CheckBox ladies = new CheckBox("Ladies");
        ladies.setSelected(tabs.contains("13"));
        ladies.setOnAction(e -> toggleTab("13", ladies.isSelected()));
        checkboxGrid.add(ladies, 1, 0);
        
        CheckBox mature = new CheckBox("Mature Female");
        mature.setSelected(tabs.contains("6"));
        mature.setOnAction(e -> toggleTab("6", mature.isSelected()));
        checkboxGrid.add(mature, 2, 0);
        
        CheckBox couples = new CheckBox("Couples");
        couples.setSelected(tabs.contains("2"));
        couples.setOnAction(e -> toggleTab("2", couples.isSelected()));
        checkboxGrid.add(couples, 3, 0);
        
        CheckBox lesbian = new CheckBox("Lesbian");
        lesbian.setSelected(tabs.contains("3"));
        lesbian.setOnAction(e -> toggleTab("3", lesbian.isSelected()));
        checkboxGrid.add(lesbian, 0, 1);
        
        CheckBox male = new CheckBox("Male");
        male.setSelected(tabs.contains("7"));
        male.setOnAction(e -> toggleTab("7", male.isSelected()));
        checkboxGrid.add(male, 1, 1);
        
        CheckBox trans = new CheckBox("Trans");
        trans.setSelected(tabs.contains("5"));
        trans.setOnAction(e -> toggleTab("5", trans.isSelected()));
        checkboxGrid.add(trans, 2, 1);
        
        layout.add(checkboxGrid, 1, row, 4, 2);
        row += 2;

        var createAccount = new Button("Create new Account");
        createAccount.setOnAction(e -> DesktopIntegration.open(site.getAffiliateLink()));
        layout.add(createAccount, 1, row++);
        GridPane.setColumnSpan(createAccount, 2);

        var deleteCookies = new Button("Delete Cookies");
        deleteCookies.setOnAction(e -> site.getHttpClient().clearCookies());
        layout.add(deleteCookies, 1, row);
        GridPane.setColumnSpan(deleteCookies, 2);

        GridPane.setMargin(username, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(password, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(createAccount, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        GridPane.setMargin(deleteCookies, new Insets(0, 0, 0, SettingsTab.CHECKBOX_MARGIN));
        return layout;
    }

    private void toggleTab(String tab, boolean selected) {
        var settings = Config.getInstance().getSettings();
        if (selected) {
            settings.xlovecamTabs.add(tab);
        } else {
            settings.xlovecamTabs.remove(tab);
        }
        save();
    }

    private List<String> getEnabledTabs() {
        return new ArrayList<>(Config.getInstance().getSettings().xlovecamTabs);
    }

}
